From 6c4f73679382693d4f2b2906d015b46565912e65 Mon Sep 17 00:00:00 2001
From: Dean Camera <dean@fourwalledcubicle.com>
Date: Mon, 11 Jul 2011 05:51:04 +0000
Subject: [PATCH] Minor documentation and style fixes.

---
 LUFA/Drivers/USB/Class/Host/MassStorage.c | 8 ++++----
 LUFA/Drivers/USB/Core/HostStandardReq.c   | 4 ++--
 LUFA/Drivers/USB/Core/HostStandardReq.h   | 4 ++--
 LUFA/ManPages/ChangeLog.txt               | 1 +
 LUFA/ManPages/LUFAPoweredProjects.txt     | 3 +++
 5 files changed, 12 insertions(+), 8 deletions(-)

diff --git a/LUFA/Drivers/USB/Class/Host/MassStorage.c b/LUFA/Drivers/USB/Class/Host/MassStorage.c
index 17f3ba70c..2b7d88ec8 100644
--- a/LUFA/Drivers/USB/Class/Host/MassStorage.c
+++ b/LUFA/Drivers/USB/Class/Host/MassStorage.c
@@ -172,12 +172,12 @@ static uint8_t MS_Host_SendCommand(USB_ClassInfo_MS_Host_t* const MSInterfaceInf
 {
 	uint8_t ErrorCode = PIPE_RWSTREAM_NoError;
 
-	SCSICommandBlock->Signature = MS_CBW_SIGNATURE;
-	SCSICommandBlock->Tag       = ++MSInterfaceInfo->State.TransactionTag;
-
-	if (MSInterfaceInfo->State.TransactionTag == 0xFFFFFFFF)
+	if (++MSInterfaceInfo->State.TransactionTag == 0xFFFFFFFF)
 	  MSInterfaceInfo->State.TransactionTag = 1;
 
+	SCSICommandBlock->Signature = MS_CBW_SIGNATURE;
+	SCSICommandBlock->Tag       = MSInterfaceInfo->State.TransactionTag;
+
 	Pipe_SelectPipe(MSInterfaceInfo->Config.DataOUTPipeNumber);
 	Pipe_Unfreeze();
 
diff --git a/LUFA/Drivers/USB/Core/HostStandardReq.c b/LUFA/Drivers/USB/Core/HostStandardReq.c
index a9451ff16..8304c2c28 100644
--- a/LUFA/Drivers/USB/Core/HostStandardReq.c
+++ b/LUFA/Drivers/USB/Core/HostStandardReq.c
@@ -238,14 +238,14 @@ uint8_t USB_Host_GetDeviceStringDescriptor(const uint8_t Index,
 	return USB_Host_SendControlRequest(Buffer);
 }
 
-uint8_t USB_Host_ClearPipeStall(const uint8_t EndpointNum)
+uint8_t USB_Host_ClearPipeStall(const uint8_t EndpointAddress)
 {
 	USB_ControlRequest = (USB_Request_Header_t)
 		{
 			.bmRequestType = (REQDIR_HOSTTODEVICE | REQTYPE_STANDARD | REQREC_ENDPOINT),
 			.bRequest      = REQ_ClearFeature,
 			.wValue        = FEATURE_SEL_EndpointHalt,
-			.wIndex        = EndpointNum,
+			.wIndex        = EndpointAddress,
 			.wLength       = 0,
 		};
 
diff --git a/LUFA/ManPages/ChangeLog.txt b/LUFA/ManPages/ChangeLog.txt
index 74bbbc2eb..de27e010f 100644
--- a/LUFA/ManPages/ChangeLog.txt
+++ b/LUFA/ManPages/ChangeLog.txt
@@ -24,6 +24,7 @@
   *   - Added board hardware driver support for the EVK1104 board
   *   - Added new HID_Host_SetIdlePeriod() function to the HID Host Class driver
   *   - Added new USB_Host_ConfigurationNumber global variable to indicate the selected configuration in an attached device
+  *   - Added RingBuffer_GetFreeCount() function to the Ring Buffer driver
   *  - Library Applications:
   *   - Added RNDIS device mode to the Webserver project
   *   - Added new incomplete AndroidAccessoryHost Host LowLevel demo
diff --git a/LUFA/ManPages/LUFAPoweredProjects.txt b/LUFA/ManPages/LUFAPoweredProjects.txt
index bb2184232..2a5be3f6c 100644
--- a/LUFA/ManPages/LUFAPoweredProjects.txt
+++ b/LUFA/ManPages/LUFAPoweredProjects.txt
@@ -93,6 +93,7 @@
  *  - USB powered Geiger Counter: http://uhrheber.wordpress.com/2011/04/28/a-usb-powered-geiger-counter-for-the-z2-and-other-computers/
  *  - Userial, a USB to Serial converter with SPI, I2C and other protocols: http://www.tty1.net/userial/
  *  - Wireless MIDI Guitar system: http://www.ise.pw.edu.pl/~wzab/wireless_guitar_system/
+ *  - Xnormidi, a C MIDI library: http://x37v.info/projects/xnormidi
  *  - XUM1541, a Commodore 64 floppy drive to USB adapter: http://www.root.org/~nate/c64/xum1541/
  *  - Zeus, a touch screen computer for music manipulation: http://www.benbengler.com/developments_zeus.html
  *
@@ -104,6 +105,7 @@
  *
  *  - Arduino Uno, the official Arduino board: http://www.arduino.cc
  *  - ARPS Locator: http://la3t.hamradio.no/lab//?id=tracker_en
+ *  - CFFA3000, a CompactFlash interface for the Apple II: http://www.dreher.net/CFforAppleII
  *  - Digital Survey Instruments Magnetometer and Pointer: http://www.digitalsurveyinstruments.com/
  *  - FinchRobot, a robot designed for educational use: http://www.finchrobot.com/
  *  - Penguino, an Arduino Board With On-Board LUFA Powered Debugger/Programmer: http://wiki.icy.com.au/PenguinoAVR
@@ -112,6 +114,7 @@
  *  - KeyGlove, an alternative input system: http://www.keyglove.net/
  *  - Many of Busware's Products: http://www.busware.de/
  *  - MIDIFighter, a USB-MIDI controller: http://www.midifighter.com/
+ *  - Norduino, a wireless Arduino: http://norduino.robomotic.com/norduino-is-now-usb-hid/
  *  - Retrode, a USB Games Console Cartridge Reader: http://www.retrode.org
  *  - SmartCardDetective, a Smart Card analysis tool: http://www.smartcarddetective.com/
  *  - USBTINY-MKII, an AVRISP-MKII Clone AVR Programmer: http://tom-itx.dyndns.org:81/~webpage/boards/USBTiny_Mkii/USBTiny_Mkii_index.php
diff --git a/LUFA/Drivers/USB/Core/HostStandardReq.h b/LUFA/Drivers/USB/Core/HostStandardReq.h
index b74aa3a3e..3358d2774 100644
--- a/LUFA/Drivers/USB/Core/HostStandardReq.h
+++ b/LUFA/Drivers/USB/Core/HostStandardReq.h
@@ -162,11 +162,11 @@
 			 *
 			 *  \ingroup Group_PipeControlReq
 			 *
 			 *  \param[in] EndpointIndex  Index of the endpoint to clear, including the endpoint's direction.
 			 *
 			 *  \return A value from the \ref USB_Host_SendControlErrorCodes_t enum to indicate the result.
 			 */
-			uint8_t USB_Host_ClearPipeStall(const uint8_t EndpointIndex);
+			uint8_t USB_Host_ClearPipeStall(const uint8_t EndpointAddress);
 
 			/** Selects a given alternative setting for the specified interface, via a SET INTERFACE standard request to
 			 *  the attached device.
@@ -162,11 +162,11 @@
 			 *  \ingroup Group_PipeControlReq
 			 *
-			 *  \param[in] EndpointIndex  Index of the endpoint to clear, including the endpoint's direction.
+			 *  \param[in] EndpointAddress  Address of the endpoint to clear, including the endpoint's direction.
 			 *
 			 *  \return A value from the \ref USB_Host_SendControlErrorCodes_t enum to indicate the result.
-- 
GitLab